<template>
    <div class="system-gas-container">
        <el-card shadow="hover">
            <div class="system-menu-search mb15">
                <el-form :inline="true" style="display: flex;align-items: flex-start;flex-wrap: wrap" >
                    <el-form-item label="日期：" >
                        <el-date-picker
                            v-model="state.tableData.listQuery.searchParams.time"
                            type="datetimerange"
                            format="YYYY-MM-DD HH:mm:ss"
                            value-format="YYYY-MM-DD HH:mm:ss"
                            range-separator="~"
                            start-placeholder="开始时间"
                            end-placeholder="结束时间"
                        />
                    </el-form-item>
                    <el-form-item label="预警级别：">
                        <el-select
                            v-model="state.tableData.listQuery.searchParams.level"
                            class="w100"
                            style="max-width: 180px"
                            size="default"
                        >
                            <el-option v-for="item in state.tableData.levelList" :key="item.label" :label="item.value" :value="item.label"></el-option>
                        </el-select>
                    </el-form-item>
                    <el-form-item label="处理状态：">
                        <el-select
                            v-model="state.tableData.listQuery.searchParams.status"
                            class="w100"
                            style="max-width: 180px"
                            size="default"
                        >
                            <el-option v-for="item in state.tableData.statusList" :key="item.label" :label="item.value" :value="item.label"></el-option>
                        </el-select>
                    </el-form-item>
                    <el-form-item label="气体：">
                        <el-select
                            v-model="state.tableData.listQuery.searchParams.gas"
                            class="w100"
                            style="max-width: 180px"
                            size="default"
                        >
                            <el-option v-for="item in state.tableData.gasList" :key="item.label" :label="item.value" :value="item.label"></el-option>
                        </el-select>
                    </el-form-item>
                    <el-button size="default" type="primary" class="ml10" @click="search()">
                        <el-icon>
                            <ele-Search />
                        </el-icon>
                        查询
                    </el-button>
                    <el-button size="default" class="ml10" @click="reset()">
                        <el-icon>
                            <RefreshLeft />
                        </el-icon>
                        重置
                    </el-button>
                </el-form>
            </div>
            <el-table :data="state.tableData.data" style="width: 100%">
                <el-table-column align="center" prop="content" label="预警内容"/>
                <el-table-column align="center" prop="warningTime" label="预警时间"/>
                <el-table-column align="center" prop="name" label="气体名称"/>
                <el-table-column align="center" prop="ppm" label="气体浓度"/>
                <el-table-column align="center" prop="level" label="预警级别" height="100">
                    <template #default="scope">
                        <span class="yellow" v-if="scope.row.level == '1'">黄色预警</span>
                        <span class="red" v-if="scope.row.level == '2'">红色预警</span>
                    </template>
                </el-table-column>
                <el-table-column align="center" prop="notifier" label="通知人员"/>
                <el-table-column align="center" prop="managePeople" label="处理人"/>
                <el-table-column align="center" prop="manageTime" label="处理时间"/>
                <el-table-column align="center" prop="status" label="处理状态">
                    <template #default="scope">
                        <span v-if="scope.row.status == '1'">未处理</span>
                        <span v-if="scope.row.status == '2'">已处理</span>
                    </template>
                </el-table-column>
                <el-table-column label="操作" show-overflow-tooltip width="140">
                    <template #default="scope">
                        <el-button size="small" text type="primary" v-if="scope.row.status == '2'" @click="openDialog('查看', scope.row)">查看</el-button>
                        <el-button size="small" text type="primary" v-if="scope.row.status == '1'" @click="openDialog('处理', scope.row)">处理</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination
                @size-change="onHandleSizeChange"
                @current-change="onHandleCurrentChange"
                class="page-position"
                :pager-count="5"
                :page-sizes="[10, 20, 30]"
                v-model:current-page="state.tableData.listQuery.pageIndex"
                background
                v-model:page-size="state.tableData.listQuery.pageSize"
                layout="total, sizes, prev, pager, next, jumper"
                :total="state.tableData.total">
            </el-pagination>
            <br />
            <br />
        </el-card>
        <info-dialog ref="infoRef" @getInfoData="initInfoData"></info-dialog>
    </div>
</template>

<script setup lang="ts">
import {reactive, ref} from "vue";
import { ElMessage, ElMessageBox } from 'element-plus'
import {InfoDataState, PeopleDataState} from "/@/types/warning";
import infoDialog from "./component/infoDialog.vue";

const infoRef = ref();
const state = reactive<InfoDataState>({
    tableData: {
        data: [
            // {
            //     id: '1',
            //     content: '【气体监测预警提示】2023年10月20日8:30 甲烷气体浓度连续超标系统判断为黄色预警，请相关负责人及时检查处置。',
            //     warningTime: '2023年10月20日 8:30',
            //     name: '甲烷',
            //     ppm: '5ppm',
            //     level: '1',
            //     notifier: '老娄、老程',
            //     managePeople: '张三',
            //     manageTime: '2023年10月20日  11:30',
            //     status: '1',
            // },
            // {
            //     id: '1',
            //     content: '【气体监测预警提示】2023年10月20日8:30 甲烷气体浓度连续超标系统判断为黄色预警，请相关负责人及时检查处置。',
            //     warningTime: '2023年10月20日 8:30',
            //     name: '甲烷',
            //     ppm: '5ppm',
            //     level: '2',
            //     notifier: '老娄、老程',
            //     managePeople: '张三',
            //     manageTime: '2023年10月20日  11:30',
            //     status: '2',
            //     method:'xxx'
            // },

        ],
        total: 0,
        loading: false,
        listQuery: {
            pageIndex: 1,
            pageSize: 10,
            searchParams:{
                time: [],
                level: '',
                status:'',
                gas: ''
            }
        },
        levelList: [
            {
                label: '1',
                value: '黄色预警'
            },
            {
                label: '2',
                value: '红色预警'
            }
        ],
        statusList: [
            {
                label: '1',
                value: '未处理'
            },
            {
                label: '2',
                value: '已处理'
            }
        ],
        gasList: [
            {
                label: '1',
                value: '甲醛'
            },
            {
                label: '2',
                value: '甲烷'
            }
        ]
    }
});

const initInfoData = () => {
    console.log("数据列表")
};
const onHandleSizeChange = (val: number) => {
    state.tableData.listQuery.pageSize = val;
    initInfoData();
};
// 分页改变
const onHandleCurrentChange = (val: number) => {
    state.tableData.listQuery.pageIndex = val;
    initInfoData();
};
const openDialog = (type: string, value: any) => {
    infoRef.value.openDialog(type, value);
};
const del = (val: any) => {
    ElMessageBox.confirm(
        '确定删除此条数据？',
        '提示',
        {
            confirmButtonText: '确定',
            cancelButtonText: '取消',
            type: 'warning',
        }
    )
        .then(() => {
            ElMessage({
                type: 'success',
                message: '删除成功',
            })
        })
};

const search = () => {
    console.log("vla",state.tableData.listQuery.searchParams)
}
const reset = () => {
    state.tableData.listQuery.searchParams.time = [];
    state.tableData.listQuery.searchParams.level = '';
    state.tableData.listQuery.searchParams.status = '';
    state.tableData.listQuery.searchParams.gas = '';
}
</script>
<style scoped lang="scss">
.yellow{
    width: 80px;
    height: 30px;
    background-color: rgb(255,223,37);
    line-height: 30px;
    color: white;
    box-shadow: 4px 4px 4px rgba(0, 0, 0, 0.2);
    padding: 3px
}
.red{
    width: 80px;
    height: 30px;
    background-color: rgb(239,90,161);
    line-height: 30px;
    color: white;
    box-shadow: 4px 4px 4px rgba(0, 0, 0, 0.2);
    padding: 3px
}
</style>